==> haskell-bytestring-strict-builder-0.4.5-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5
id: bytestring-strict-builder-0.4.5-IOwOBZPdVgV4Xi1dWXYwhk
key: bytestring-strict-builder-0.4.5-IOwOBZPdVgV4Xi1dWXYwhk
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
abi: 506c5a954d1fb158d572034283917e53
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-strict-builder-0.4.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-strict-builder-0.4.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/bytestring-strict-builder-0.4.5
hs-libraries: HSbytestring-strict-builder-0.4.5-IOwOBZPdVgV4Xi1dWXYwhk
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1 semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-strict-builder-0.4.5-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5
id: bytestring-strict-builder-0.4.5-1bgh4ppFFrNo1kPRheKse
key: bytestring-strict-builder-0.4.5-1bgh4ppFFrNo1kPRheKse
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
abi: 52f140bb59ce1e275e7234197e175824
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-strict-builder-0.4.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-strict-builder-0.4.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/bytestring-strict-builder-0.4.5
hs-libraries: HSbytestring-strict-builder-0.4.5-1bgh4ppFFrNo1kPRheKse
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1 semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
